@@ -108,6 +108,16 @@ sub to_psgi {
     ];
 }
 
+sub as_string {
+    my ($self) = @_;
+    return join("",
+        $self->status_line . "\015\012",
+        $self->headers->as_string,
+        "\015\012",
+        $self->content,
+    );
+}
+
 sub as_hashref {
     my $self = shift;
 
@@ -170,6 +180,10 @@ sub encoding {
 1;
 __END__
 
+=encoding utf-8
+
+=for stopwords charsets
+
 =head1 NAME
 
 Furl::Response - Response object for Furl
